Electrostatic Scoring
=====================

PyTorch Implementation
~~~~~~~~~~~~~~~~~~~~~~

.. automodule:: shepherd_score.score.electrostatic_scoring
   :members:
   :undoc-members:
   :show-inheritance:

NumPy Implementation
~~~~~~~~~~~~~~~~~~~~

.. automodule:: shepherd_score.score.electrostatic_scoring_np
   :members:
   :undoc-members:
   :show-inheritance:

JAX Implementation
~~~~~~~~~~~~~~~~~~

.. automodule:: shepherd_score.score.electrostatic_scoring_jax
   :members:
   :undoc-members:
   :show-inheritance:
